% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllGenerics.R, R/fit.R
\docType{methods}
\name{fit}
\alias{fit}
\alias{fit-method}
\alias{fit,CountMatrix,missing-method}
\alias{fit,CountMatrix,numeric-method}
\title{Frequency Increment Test}
\usage{
fit(object, dates, ...)

\S4method{fit}{CountMatrix,missing}(object)

\S4method{fit}{CountMatrix,numeric}(object, dates)
}
\arguments{
\item{object}{A \link[arkhe:CountMatrix-class]{arkhe::CountMatrix} object.}

\item{dates}{A \code{\link{numeric}} vector of dates.}

\item{...}{Currently not used.}
}
\value{
An \linkS4class{IncrementTest} object.
}
\description{
Frequency Increment Test
}
\details{
The Frequency Increment Test (FIT) rejects neutrality if the distribution
of normalized variant frequency increments exhibits a mean that deviates
significantly from zero.
}
\examples{
data("merzbach", package = "folio")

## Coerce the merzbach dataset to a count matrix
## Keep only decoration types that have a maximum frequency of at least 50
keep <- apply(X = merzbach, MARGIN = 2, FUN = function(x) max(x) >= 50)
counts <- as_count(merzbach[, keep])

## Group by phase
## We use the row names as time coordinates (roman numerals)
set_dates(counts) <- as.numeric(utils::as.roman(rownames(counts)))

## Frequency Increment Test
freq <- fit(counts)

## Plot time vs abundance and highlight selection
plot(freq)
plot(freq, roll = TRUE, window = 5)
}
\references{
Feder, A. F., Kryazhimskiy, S. & Plotkin, J. B. (2014). Identifying
Signatures of Selection in Genetic Time Series. \emph{Genetics}, 196(2):
509-522. \doi{10.1534/genetics.113.158220}.
}
\seealso{
\link[=plot_fit]{plot()}

Other chronological analysis: 
\code{\link{aoristic}()},
\code{\link{apportion}()},
\code{\link{roc}()}
}
\author{
N. Frerebeau
}
\concept{chronological analysis}
